@@ -1,14 +1,14 @@
 #ifndef lint
-static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/readPNG.c,v 1.6 1998/04/29 23:23:13 unammx Exp $";
+static char rcsId[]="$Header: /cvs/gnome/gnome-libs/gtk-xmhtml/readPNG.c,v 1.7 1998/06/29 06:32:14 tromey Exp $";
 #endif
 /*****
 * readPNG.c : XmHTML png image loading routines
 *
-* This file Version	$Revision: 1.6 $
+* This file Version	$Revision: 1.7 $
 *
 * Creation date:		Wed Feb 19 03:21:11 GMT+0100 1997
-* Last modification: 	$Date: 1998/04/29 23:23:13 $
-* By:					$Author: unammx $
+* Last modification: 	$Date: 1998/06/29 06:32:14 $
+* By:					$Author: tromey $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -37,6 +37,9 @@ static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/readPN
 /*****
 * ChangeLog 
 * $Log: readPNG.c,v $
+* Revision 1.7  1998/06/29 06:32:14  tromey
+* added gnome-config to .cvsignore
+*
 * Revision 1.6  1998/04/29 23:23:13  unammx
 * 1998-04-29  Miguel de Icaza  <miguel@nuclecu.unam.mx>
 *
@@ -310,7 +313,7 @@ _XmHTMLReadPNG(TWidget html, ImageBuffer *ib)
 
 	/* by now we already know this is a png */
 	ib->next = 8;
-#ifndef __alpha__
+#if 0
 	/* FIXME:  Upgrade my png instaed of this -- mig */
 	png_set_sig_bytes(png_ptr, 8);
 #endif
