@@ -7,9 +7,13 @@
  * improvements and rearrangement by Miguel,
  * and I don't know what you other people did :)
  */
+#include "config.h"
+#include <glib.h>
 #include "libgnome/gnome-defs.h"
+#include "libgnome/gnome-i18nP.h"
 #include "libgnome/gnome-util.h"
 #include "libgnome/gnome-config.h"
+#include "libgnomeui/gnome-preferences.h"
 #include "gnome-app.h"
 #include <string.h>
 #include <gtk/gtk.h>
@@ -26,7 +30,7 @@ static GtkWindowClass *parent_class = NULL;
 
 /* keep in sync with GnomeAppWidgetPositionType */
 static char *locations [] = {
-	"top", "botton", "left", "right", "float,", NULL
+	"top", "bottom", "left", "right", "float,", NULL
 };
 
 static GnomeAppWidgetPositionType
@@ -92,6 +96,7 @@ static void
 gnome_app_init(GnomeApp *app)
 {
 	app->menubar = app->toolbar = app->contents = NULL;
+	app->statusbar = NULL;
 	app->table = gtk_table_new(4, 3, FALSE);
 	gtk_widget_show(app->table);
 	gtk_container_add(GTK_CONTAINER(app), app->table);
@@ -99,6 +104,17 @@ gnome_app_init(GnomeApp *app)
 	app->pos_menubar = app->pos_toolbar = GNOME_APP_POS_TOP;
 }
 
+void 
+gnome_app_construct(GnomeApp *app, gchar *appname, char *title)
+{
+	app->name = g_strdup (appname);
+	app->prefix = g_copy_strings ("/", appname, "/", NULL);
+	
+	if (title)
+		gtk_window_set_title(GTK_WINDOW(app), title);
+}
+
+
 GtkWidget *
 gnome_app_new(gchar *appname, char *title)
 {
@@ -108,11 +124,7 @@ gnome_app_new(gchar *appname, char *title)
 	retval = gtk_type_new(gnome_app_get_type());
 	app = GNOME_APP (retval);
 
-	app->name = g_strdup (appname);
-	app->prefix = g_copy_strings ("/", appname, "/", NULL);
-	
-	if (title)
-		gtk_window_set_title(GTK_WINDOW(retval), title);
+	gnome_app_construct(app, appname, title);
 
 	return retval;
 }
@@ -148,13 +160,16 @@ gnome_app_configure_positions (GnomeApp *app)
 		if (app->menubar->parent->parent)
 			gtk_container_remove (GTK_CONTAINER(app->table), handlebox);
 
+		/* FUCK ME ... what is pos_menubar? */
+		g_message("pos_menubar: %d\n", app->pos_menubar);
+
 		gtk_table_attach(GTK_TABLE(app->table),
 				 handlebox,
 				 0, 3,
 				 (app->pos_menubar == GNOME_APP_POS_TOP)?0:2,
 				 (app->pos_menubar == GNOME_APP_POS_TOP)?1:3,
 				 GTK_EXPAND | GTK_FILL,
-				 GTK_SHRINK,
+				 0,
 				 0, 0);
 		gtk_widget_show (handlebox);
 		gtk_widget_unref (handlebox);
@@ -182,7 +197,7 @@ gnome_app_configure_positions (GnomeApp *app)
 					 (app->pos_toolbar==GNOME_APP_POS_LEFT)?0:2,
 					 (app->pos_toolbar==GNOME_APP_POS_LEFT)?1:3,
 					 offset, 3,
-					 GTK_SHRINK,
+					 0,
 					 GTK_EXPAND | GTK_FILL,
 					 0, 0);
 		}
@@ -200,7 +215,7 @@ gnome_app_configure_positions (GnomeApp *app)
 					 ((app->pos_toolbar==GNOME_APP_POS_TOP)?0:2) + moffset,
 					 ((app->pos_toolbar==GNOME_APP_POS_TOP)?1:3) + moffset,
 					 GTK_EXPAND | GTK_FILL,
-					 GTK_SHRINK,
+					 0,
 					 0, 0);
 		}
 		gtk_widget_show (handlebox);
@@ -337,8 +352,8 @@ make_button_menubar(GnomeApp *app)
 	int i;
 	
 	menu_menu = gtk_menu_new();
-	menuitems[0] = gtk_menu_item_new_with_label("Top");
-	menuitems[1] = gtk_menu_item_new_with_label("Bottom");
+	menuitems [0] = gtk_menu_item_new_with_label(_("Top"));
+	menuitems [1] = gtk_menu_item_new_with_label(_("Bottom"));
 
 	for(i = 0; i < 2; i++)
 	{
@@ -349,42 +364,58 @@ make_button_menubar(GnomeApp *app)
 	}
 }
 
+static void
+configure_toolbar (GtkMenuItem *menu_item, GnomeApp *app)
+{
+	/* FIXME: add toolbar configuration dialog box here */
+}
+			       
 static void
 make_button_toolbar (GnomeApp *app)
 {
 	int i;
 
-	toolbar_menu = gtk_menu_new();
+	toolbar_menu = gtk_menu_new ();
 
-	toolitems[0] = gtk_menu_item_new_with_label("Top");
-	toolitems[1] = gtk_menu_item_new_with_label("Bottom");
-	toolitems[2] = gtk_menu_item_new_with_label("Left");
-	toolitems[3] = gtk_menu_item_new_with_label("Right");
+	toolitems [0] = gtk_menu_item_new_with_label(_("Top"));
+	toolitems [1] = gtk_menu_item_new_with_label(_("Bottom"));
+	toolitems [2] = gtk_menu_item_new_with_label(_("Left"));
+	toolitems [3] = gtk_menu_item_new_with_label(_("Right"));
+	toolitems [4] = gtk_menu_item_new_with_label(_("Configure toolbar"));
 
-	for(i = 0; i < 4; i++)
+	/* Change 4 to 5 to do the toolbar configuration code */
+	for (i = 0; i < 4; i++)
 	{
-		gtk_widget_show(toolitems[i]);
-		gtk_menu_append(GTK_MENU(toolbar_menu), toolitems[i]);
-		gtk_signal_connect(GTK_OBJECT(toolitems[i]), "activate",
-				   GTK_SIGNAL_FUNC(gnome_app_setpos_activate_toolbar), app);
+		GtkSignalFunc function;
+		
+		gtk_widget_show (toolitems [i]);
+		gtk_menu_append (GTK_MENU (toolbar_menu), toolitems [i]);
+		
+		if (i == 4)
+			function = GTK_SIGNAL_FUNC (configure_toolbar);
+		else
+			function = GTK_SIGNAL_FUNC (gnome_app_setpos_activate_toolbar);
+		
+		gtk_signal_connect (GTK_OBJECT(toolitems[i]), "activate", function, app);
 	}
 }
 
 static void
 gnome_app_rightclick_menubar(GtkWidget *widget, GdkEventButton *event, GnomeApp *app)
 {
-	g_return_if_fail(app != NULL);
-	g_return_if_fail(GNOME_IS_APP(app));
+	g_return_if_fail (app != NULL);
+	g_return_if_fail (GNOME_IS_APP (app));
 
-	if(menu_menu == NULL) make_button_menubar (app);
+	if (menu_menu == NULL)
+		make_button_menubar (app);
 
-	if(GTK_WIDGET_VISIBLE(menu_menu))
-		gtk_menu_popdown(GTK_MENU(menu_menu));
+	if (GTK_WIDGET_VISIBLE (menu_menu))
+		gtk_menu_popdown (GTK_MENU (menu_menu));
 
 	if(event->button != 3)
 		return;
 
-	gtk_menu_popup(GTK_MENU(menu_menu),
+	gtk_menu_popup (GTK_MENU (menu_menu),
 		       NULL, NULL, NULL, NULL,
 		       event->button,
 		       event->time);
@@ -396,12 +427,20 @@ gnome_app_rightclick_toolbar(GtkWidget *widget, GdkEventButton *event, GnomeApp
 	g_return_if_fail(app != NULL);
 	g_return_if_fail(GNOME_IS_APP(app));
 
-	if(toolbar_menu == NULL) make_button_toolbar (app);
+	/* Double click on handlebox, reparents */
+	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS){
+		/* FIXME: Mhm, there is no easy way to tell the handlebox to reparent itself */
+		return;
+	}
+		
+	/* Right click on handlebox, brings up menu */
+	if (toolbar_menu == NULL)
+		make_button_toolbar (app);
 
-	if(GTK_WIDGET_VISIBLE(toolbar_menu))
+	if (GTK_WIDGET_VISIBLE(toolbar_menu))
 		gtk_menu_popdown(GTK_MENU(toolbar_menu));
 
-	if(event->button != 3)
+	if (event->button != 3)
 		return;
 
 	gtk_menu_popup(GTK_MENU(toolbar_menu),
@@ -455,16 +494,26 @@ gnome_app_set_menus (GnomeApp *app,
 	GnomeAppWidgetPositionType pos = GNOME_APP_POS_TOP;
 	char *location = NULL;
 	GtkWidget *hb;
+#ifdef GTK_HAVE_FEATURES_1_1_0
+	GtkAccelGroup *ag;
+#else
 	GtkAcceleratorTable *at;
-
+#endif
 	g_return_if_fail(app != NULL);
 	g_return_if_fail(GNOME_IS_APP(app));
 	g_return_if_fail(app->menubar == NULL);
 	g_return_if_fail(menubar != NULL);
 	g_return_if_fail(GTK_IS_MENU_BAR(menubar));
 
-	hb = gtk_handle_box_new();
-	gtk_widget_show(hb);
+	if ( gnome_preferences_get_menubar_handlebox() ) {
+	  hb = gtk_handle_box_new();
+	  gtk_widget_show(hb);
+	}
+	else {
+	  hb = gtk_event_box_new();
+	  gtk_widget_set_events(hb, GDK_BUTTON_PRESS_MASK);
+	}
+
 	app->menubar = GTK_WIDGET(menubar);
 
 	gtk_signal_connect(GTK_OBJECT(hb), "button_press_event",
@@ -489,10 +538,15 @@ gnome_app_set_menus (GnomeApp *app,
 		g_free (location);
 		gnome_config_pop_prefix ();
 	}
-
-	at = gtk_object_get_data(GTK_OBJECT(app), "GtkAcceleratorTable");
-	if(at && !g_list_find(GTK_WINDOW(app)->accelerator_tables, at))
-		gtk_window_add_accelerator_table(GTK_WINDOW(app), at);
+#ifdef GTK_HAVE_FEATURES_1_1_0
+	ag = gtk_object_get_data(GTK_OBJECT(app), "GtkAccelGroup");
+	if (ag && !g_slist_find(gtk_accel_groups_from_object (GTK_OBJECT (app)), ag))
+	        gtk_window_add_accel_group(GTK_WINDOW(app), ag);
+#else
+        at = gtk_object_get_data(GTK_OBJECT(app), "GtkAcceleratorTable");
+        if(at && !g_list_find(GTK_WINDOW(app)->accelerator_tables, at))
+                gtk_window_add_accelerator_table(GTK_WINDOW(app), at);
+#endif
 }
 
 void
@@ -502,18 +556,33 @@ gnome_app_set_toolbar (GnomeApp *app,
 	GnomeAppWidgetPositionType pos = GNOME_APP_POS_TOP;
 	GtkWidget *hb;
 	char *location;
+#ifdef GTK_HAVE_FEATURES_1_1_0
+	GtkAccelGroup *ag;
+#else
 	GtkAcceleratorTable *at;
-
+#endif
 	g_return_if_fail(app != NULL);
 	g_return_if_fail(GNOME_IS_APP(app));
 	g_return_if_fail(toolbar != NULL);
 	g_return_if_fail(app->toolbar == NULL);
 
-	hb = gtk_handle_box_new();
-	gtk_widget_show(hb);
-	app->toolbar = GTK_WIDGET(toolbar);
-	gtk_signal_connect(GTK_OBJECT(hb), "button_press_event",
-			   GTK_SIGNAL_FUNC(gnome_app_rightclick_toolbar), app);
+	if ( gnome_preferences_get_toolbar_handlebox() ) {
+	  hb = gtk_handle_box_new ();
+	  gtk_widget_show (hb);
+	}
+	else {
+	  hb = gtk_event_box_new();
+	  gtk_widget_set_events(hb, GDK_BUTTON_PRESS_MASK);
+	}
+
+#ifdef GTK_RELIEF_NONE
+	if ( ! gnome_preferences_get_toolbar_relief() ) {
+	  gtk_toolbar_set_button_relief(toolbar, GTK_RELIEF_NONE);
+	}
+#endif
+	app->toolbar = GTK_WIDGET (toolbar);
+	gtk_signal_connect (GTK_OBJECT(hb), "button_press_event",
+			    GTK_SIGNAL_FUNC (gnome_app_rightclick_toolbar), app);
 	gtk_widget_show(app->toolbar);
 	gtk_container_add(GTK_CONTAINER(hb), app->toolbar);
 
@@ -529,9 +598,15 @@ gnome_app_set_toolbar (GnomeApp *app,
 	}
 	else
 		gnome_app_toolbar_set_position (app, pos);
-	at = gtk_object_get_data(GTK_OBJECT(app), "GtkAcceleratorTable");
-	if(at && !g_list_find(GTK_WINDOW(app)->accelerator_tables, at))
-		gtk_window_add_accelerator_table(GTK_WINDOW(app), at);
+#ifdef GTK_HAVE_FEATURES_1_1_0
+	ag = gtk_object_get_data(GTK_OBJECT(app), "GtkAccelGroup");
+	if (ag && !g_slist_find(gtk_accel_groups_from_object (GTK_OBJECT (app)), ag))
+	        gtk_window_add_accel_group(GTK_WINDOW(app), ag);
+#else
+        at = gtk_object_get_data(GTK_OBJECT(app), "GtkAcceleratorTable");
+        if(at && !g_list_find(GTK_WINDOW(app)->accelerator_tables, at))
+                gtk_window_add_accelerator_table(GTK_WINDOW(app), at);
+#endif
 }
 
 void
@@ -551,12 +626,10 @@ gnome_app_set_statusbar (GnomeApp *app,
 			  0, 3,
 			  3, 4,
 			  GTK_EXPAND | GTK_FILL,
-			  GTK_SHRINK,
+			  0,
 			  0, 0);
 }
 
 
 
 
-
-
