@@ -17,7 +17,6 @@
  */
 
 #include <config.h>
-#include <stdarg.h>
 
 #include "gnome-dialog.h"
 #include "libgnome/gnome-util.h"
@@ -173,10 +172,21 @@ gnome_dialog_init (GnomeDialog *dialog)
   dialog->just_hide = FALSE;
   dialog->click_closes = FALSE;
   dialog->buttons = NULL;
+  dialog->parent = NULL;
 
-  dialog->accelerators = gtk_accelerator_table_new();
-  gtk_window_add_accelerator_table (GTK_WINDOW(dialog), 
+  GTK_WINDOW(dialog)->type = gnome_preferences_get_dialog_type();
+  gtk_window_position(GTK_WINDOW(dialog), 
+		      gnome_preferences_get_dialog_position());
+  
+#ifdef GTK_HAVE_FEATURES_1_1_0
+  dialog->accelerators = gtk_accel_group_new();
+  gtk_window_add_accel_group (GTK_WINDOW(dialog), 
 				    dialog->accelerators);
+#else
+  dialog->accelerators = gtk_accelerator_table_new();
+  gtk_window_add_accelerator_table (GTK_WINDOW(dialog),
+                                    dialog->accelerators);
+#endif
 
   bf = gtk_frame_new (NULL);
   gtk_frame_set_shadow_type (GTK_FRAME (bf), GTK_SHADOW_OUT);
@@ -216,39 +226,119 @@ gnome_dialog_init (GnomeDialog *dialog)
   gtk_widget_show (dialog->action_area);
 }
 
+void       
+gnome_dialog_construct (GnomeDialog * dialog,
+			const gchar * title,
+			va_list ap)
+{
+  gchar * button_name;
+  
+  if (title)
+    gtk_window_set_title (GTK_WINDOW (dialog), title);
+  
+  while (TRUE) {
+    
+    button_name = va_arg (ap, gchar *);
+    
+    if (button_name == NULL) {
+      break;
+    }
+    
+    gnome_dialog_append_button( dialog, 
+				button_name);
+  };  
+}
+
+void gnome_dialog_constructv (GnomeDialog * dialog,
+			      const gchar * title,
+			      const gchar ** buttons)
+{
+  const gchar * button_name;
+  
+  if (title)
+    gtk_window_set_title (GTK_WINDOW (dialog), title);
+  
+  while (TRUE) {
+    
+    button_name = *buttons++;
+    
+    if (button_name == NULL) {
+      break;
+    }
+    
+    gnome_dialog_append_button( dialog, 
+				button_name);
+  };  
+}
+
+
 
 GtkWidget* gnome_dialog_new            (const gchar * title,
 					...)
 {
   va_list ap;
   GnomeDialog *dialog;
-  gchar * button_name;
-	
-  va_start (ap, title);
 	
   dialog = gtk_type_new (gnome_dialog_get_type ());
 
-  if (title)
-    gtk_window_set_title (GTK_WINDOW (dialog), title);
+  va_start (ap, title);
+  
+  gnome_dialog_construct(dialog, title, ap);
 
-  while (TRUE) {
-
-    button_name = va_arg (ap, gchar *);
-
-    if (button_name == NULL) {
-      break;
-    }
-	  
-    gnome_dialog_append_buttons( dialog, 
-				 button_name, 
-				 NULL );
-  };
-
-  va_end (ap);
+  va_end(ap);
 
   return GTK_WIDGET (dialog);
 }
 
+GtkWidget* gnome_dialog_newv            (const gchar * title,
+					 const gchar ** buttons)
+{
+  GnomeDialog *dialog;
+	
+  dialog = gtk_type_new (gnome_dialog_get_type ());
+
+  gnome_dialog_constructv(dialog, title, buttons);
+
+  return GTK_WIDGET (dialog);
+}
+
+void       gnome_dialog_set_parent     (GnomeDialog * dialog,
+					GtkWindow   * parent)
+{
+  g_return_if_fail(dialog != NULL);
+  g_return_if_fail(GNOME_IS_DIALOG(dialog));
+  g_return_if_fail(parent != NULL);
+  g_return_if_fail(GTK_IS_WINDOW(parent));
+
+  dialog->parent = parent;
+
+  if ( gnome_preferences_get_dialog_centered() ) {
+
+    /* User wants us to center over parent */
+
+    gint x, y, w, h, dialog_x, dialog_y;
+
+    if ( ! GTK_WIDGET_VISIBLE(parent)) return; /* Can't get its
+						  size/pos */
+
+    /* Throw out other positioning */
+    gtk_window_position(GTK_WINDOW(dialog),GTK_WIN_POS_NONE);
+
+    gdk_window_get_origin (GTK_WIDGET(parent)->window, &x, &y);
+    gdk_window_get_size   (GTK_WIDGET(parent)->window, &w, &h);
+
+    /* The problem here is we don't know how big the dialog is.
+       So "centered" isn't really true. We'll go with 
+       "kind of more or less on top" */
+
+    dialog_x = x + w/4;
+    dialog_y = y + h/4;
+
+    gtk_widget_set_uposition(GTK_WIDGET(dialog), dialog_x, dialog_y); 
+  }
+}
+
+
 void       gnome_dialog_append_buttons (GnomeDialog * dialog,
 					const gchar * first,
 					...)
@@ -262,6 +352,19 @@ void       gnome_dialog_append_buttons (GnomeDialog * dialog,
   va_start(ap, first);
 
   while(button_name != NULL) {
+    gnome_dialog_append_button (dialog, button_name);
+    button_name = va_arg (ap, gchar *);
+  }
+  va_end(ap);
+}
+
+void       gnome_dialog_append_button (GnomeDialog * dialog,
+				       const gchar * button_name)
+{
+  g_return_if_fail(dialog != NULL);
+  g_return_if_fail(GNOME_IS_DIALOG(dialog));
+
+  if (button_name != NULL) {
     GtkWidget *button;
     
     button = gnome_stock_or_ordinary_button (button_name);
@@ -276,10 +379,19 @@ void       gnome_dialog_append_buttons (GnomeDialog * dialog,
 			      dialog);
     
     dialog->buttons = g_list_append (dialog->buttons, button);
-
-    button_name = va_arg (ap, gchar *);
   }
-  va_end(ap);
+}
+
+void       gnome_dialog_append_buttonsv (GnomeDialog * dialog,
+					 const gchar ** buttons)
+{
+  g_return_if_fail(dialog != NULL);
+  g_return_if_fail(GNOME_IS_DIALOG(dialog));
+
+  while(*buttons != NULL) {
+    gnome_dialog_append_button (dialog, *buttons);
+    buttons++;
+  }
 }
 
 void
@@ -341,6 +453,9 @@ gnome_dialog_quit_run(GnomeDialog *dialog,
 gint
 gnome_dialog_run_modal(GnomeDialog *dialog)
 {
+  g_return_val_if_fail(dialog != NULL, -1);
+  g_return_val_if_fail(GNOME_IS_DIALOG(dialog), -1);
+
   gnome_dialog_set_modal(dialog);
   return gnome_dialog_run(dialog);
 }
@@ -355,8 +470,7 @@ gnome_dialog_run(GnomeDialog *dialog)
   g_return_val_if_fail(GNOME_IS_DIALOG(dialog), -1);
 
   was_modal = dialog->modal;
-  gnome_dialog_set_modal(dialog);
-  gnome_dialog_close_hides(dialog, TRUE);
+  if (!was_modal) gnome_dialog_set_modal(dialog);
 
   ri.clicked_id =
     gtk_signal_connect(GTK_OBJECT(dialog), "clicked",
@@ -373,8 +487,6 @@ gnome_dialog_run(GnomeDialog *dialog)
 
   gtk_main();
 
-  gtk_widget_hide(GTK_WIDGET(dialog));
-
   if(!was_modal)
     {
       /* It would be nicer if gnome_dialog_set_modal() took a
@@ -392,6 +504,38 @@ gnome_dialog_run(GnomeDialog *dialog)
   return ri.button_number;
 }
 
+gint
+gnome_dialog_run_and_hide (GnomeDialog * dialog)
+{
+  gint r;
+
+  g_return_val_if_fail(dialog != NULL, -1);
+  g_return_val_if_fail(GNOME_IS_DIALOG(dialog), -1);  
+
+  gnome_dialog_close_hides(dialog, TRUE);
+
+  r = gnome_dialog_run(dialog);
+
+  gnome_dialog_close(dialog); /* Causes a hide. */
+  return r;
+}
+
+gint 
+gnome_dialog_run_and_destroy (GnomeDialog * dialog)
+{
+  gint r;
+
+  g_return_val_if_fail(dialog != NULL, -1);
+  g_return_val_if_fail(GNOME_IS_DIALOG(dialog), -1);  
+
+  gnome_dialog_close_hides(dialog, FALSE);
+
+  r = gnome_dialog_run(dialog);
+
+  gnome_dialog_close(dialog); /* Causes a destroy. */
+  return r;
+}
+
 void
 gnome_dialog_set_default (GnomeDialog *dialog,
 			  gint button)
@@ -483,6 +627,30 @@ void       gnome_dialog_button_connect (GnomeDialog *dialog,
 #endif
 }
 
+void       gnome_dialog_button_connect_object (GnomeDialog *dialog,
+					       gint button,
+					       GtkSignalFunc callback,
+					       GtkObject * obj)
+{
+  GList * list;
+
+  g_return_if_fail(dialog != NULL);
+  g_return_if_fail(GNOME_IS_DIALOG(dialog));
+
+  list = g_list_nth (dialog->buttons, button);
+
+  if (list && list->data) {
+    gtk_signal_connect_object (GTK_OBJECT(list->data), "clicked",
+			       callback, obj);
+    return;
+  }
+#ifdef GNOME_ENABLE_DEBUG
+  /* If we didn't find the button, complain */
+  g_warning("Button number %d does not appear to exist\n", button); 
+#endif
+}
+
+
 void       gnome_dialog_set_accelerator(GnomeDialog * dialog,
 					gint button,
 					const guchar accelerator_key,
@@ -496,12 +664,22 @@ void       gnome_dialog_set_accelerator(GnomeDialog * dialog,
   list = g_list_nth (dialog->buttons, button);
 
   if (list && list->data) {
-
+#ifdef GTK_HAVE_FEATURES_1_1_0
+/*FIXME*/
+    gtk_widget_add_accelerator(GTK_WIDGET(list->data),
+			       "clicked",
+			       dialog->accelerators,
+			       accelerator_key,
+			       accelerator_mods,
+			       GTK_ACCEL_VISIBLE);
+#else
     gtk_widget_install_accelerator(GTK_WIDGET(list->data),
-				   dialog->accelerators,
-				   "clicked",
-				   accelerator_key,
-				   accelerator_mods);
+                                   dialog->accelerators,
+                                   "clicked",
+                                   accelerator_key,
+                                   accelerator_mods);
+
+#endif
     
     return;
   }
@@ -591,8 +769,10 @@ static void gnome_dialog_destroy (GtkObject *dialog)
 
   g_list_free(GNOME_DIALOG (dialog)->buttons);
 
-  if (GNOME_DIALOG(dialog)->accelerators) 
+#ifndef GTK_HAVE_FEATURES_1_1_0
+  if (GNOME_DIALOG(dialog)->accelerators)
     gtk_accelerator_table_unref(GNOME_DIALOG(dialog)->accelerators);
+#endif
 
   if (GTK_OBJECT_CLASS(parent_class)->destroy)
     (* (GTK_OBJECT_CLASS(parent_class)->destroy))(dialog);
@@ -645,6 +825,166 @@ static void gnome_dialog_show (GtkWidget * d)
 
 /****************************************************************
   $Log: gnome-dialog.c,v $
+  Revision 1.37  1998/08/05 15:17:09  owen
+  Wed Aug  5 11:19:56 1998  Owen Taylor  <otaylor@redhat.com>
+
+  	* gnome-dialog.c (gnome_dialog_destroy): Don't remove
+  	  the accelerator group - GTK+ handles it for us.
+
+  	* gnome-app.c gnome-app-helper.c: Added gtk-1.1 code to check
+  	  if AccelGroup is already attached before attaching it
+  	  again.
+
+  Revision 1.36  1998/07/27 14:37:10  pavlov
+  replaced GTK_HAVE_ACCEL_GROUP with GTK_HAVE_FEATURES_1_1_0
+
+  This should allow it to compile correctly with the new gtk 1.1.0 that timj
+  broke changed on us ;)
+
+  -pav
+
+  Revision 1.35  1998/07/25 03:07:40  hp
+
+
+  Fri Jul 24 19:54:43 1998  Havoc Pennington  <hp@pobox.com>
+
+          * gnome-scores.c (gnome_scores_new): Use construct to set
+          the title and buttons.
+
+          * gnome-app-util.c: Switch to parented dialogs.
+
+  	* gnome-dialog-util.h, gnome-dialog-util.c: Added "parented"
+  	versions of these. The old versions are not really necessary
+  	anymore because you can just pass NULL for parent, but they
+  	save typing I guess.
+
+  	* gnome-preferences.h: New functions for dialog position, whether
+  	to attempt dialog-over-parent centering, whether dialogs are
+  	TOPLEVEL or DIALOG.
+
+  	* gnome-dialog.c (gnome_dialog_newv): Remove unused variable.
+  	(gnome_dialog_set_parent): New function, allows setting a parent
+  	the dialog should be centered over.
+
+  Sat Jul 25 02:51:12 1998  Simon Kagedal  <simon@sdf.se>
+
+          * gnome-scores.c, gnome-scores.h:
+          made the GnomeScore dialog inherit from GnomeDialog
+          instead of GtkWindow
+
+  Revision 1.34  1998/07/18 17:53:31  hp
+
+
+  Um, someone broke every dialog in Gnome without so much as a change log
+  entry. However, the vector constructor is nice.
+
+  Sat Jul 18 12:42:09 1998  Havoc Pennington  <hp@pobox.com>
+
+  * gnome-dialog.c (gnome_dialog_constructv): Use append_button,
+  not append_buttons without NULL termination.
+  (gnome_dialog_construct): Same.
+  (gnome_dialog_new): Reverted last change. Use the construct
+  function rather than cut-and-pasting it.
+
+  Revision 1.33  1998/07/17 23:37:03  yacc
+  provide ...v-forms of functions using varargs.
+
+  Revision 1.32  1998/07/15 03:59:15  hp
+
+
+  Tue Jul 14 22:47:33 1998  Havoc Pennington  <hp@pobox.com>
+
+  * gnome-app.h, gnome-app.c, gnome-dialog.h, gnome-dialog.c:
+  Added "construct" functions. The gnome-dialog one takes a va_list
+  which is kind of weird; if there's a good alternative I'd like
+  to use it instead.
+
+  Revision 1.31  1998/07/10 08:53:22  timj
+  Fri Jul 10 10:19:38 1998  Tim Janik  <timj@gtk.org>
+
+          * gnome-app-helper.c (gnome_app_do_menu_creation):
+          * gnome-stock.c (gnome_stock_menu_item):
+          create GtkAccelLabel if GTK_HAVE_FEATURES_1_1_0, so accelerators are
+          visible.
+
+  Revision 1.30  1998/07/03 00:51:57  hp
+
+
+  This fixes a couple of bugs in my Sunday commits, but breaks things: namely,
+  your handlebox preferences if you've set them, and gnome_dialog_run_and_die
+  is renamed if anyone had used it. Sorry it didn't get in on Monday, all that
+  CVS confusion.
+
+  Mon Jun 29 14:10:48 1998  Havoc Pennington  <hp@pobox.com>
+
+  * gnome-preferences.h, gnome-preferences.c
+  (gnome_preferences_get_toolbar_relief,
+  gnome_preferences_set_toolbar_relief): Whether the toolbar buttons
+  have the beveled edge.
+  * gnome-app.c (gnome_app_set_toolbar): Turn off the toolbar button
+  relief if user requested it.
+  * gnome-preferences.c (gnome_preferences_load): Oops, forgot to
+  push a new prefix for the GnomeApp stuff, it was being saved under
+  Dialog prefs.
+  * gnome-dialog.h, gnome-dialog.c (gnome_dialog_run_and_die):
+  Renamed to run_and_destroy - run_and_die was cute at 2 am, but
+  probably not a good name. ;-)
+
+  Revision 1.29  1998/06/29 08:06:27  hp
+
+
+  I think Elliot and I talked about the dialog changes this time, and there
+  are now two functions to make both of us happy. The other change allows
+  turning off the handlebox for the menubar and toolbar, I think that was
+  mentioned recently.
+
+  Mon Jun 29 03:04:30 1998  Havoc Pennington  <hp@pobox.com>
+
+  * TODO: Updated a little.
+
+  Mon Jun 29 02:58:15 1998  Havoc Pennington  <hp@pobox.com>
+
+  * gnome-preferences.h, gnome-preferences.c
+  (gnome_preferences_get_toolbar_handlebox,
+  gnome_preferences_set_toolbar_handlebox,
+  gnome_preferences_get_menubar_handlebox,
+  gnome_preferences_set_menubar_handlebox): New functions.
+
+  * gnome-app.c (gnome_app_set_menus): Obey preferences for
+  handlebox.
+  (gnome_app_set_toolbar): Obey handlebox prefs.
+
+  Mon Jun 29 02:52:10 1998  Havoc Pennington  <hp@pobox.com>
+
+  * gnome-dialog.h, gnome-dialog.c (gnome_dialog_run): Take out the
+  hide stuff.
+  (gnome_dialog_run_and_hide): Do what gnome_dialog_run used to do.
+  (gnome_dialog_run_and_die):  Run and then destroy the dialog.
+  (gnome_dialog_button_connect_object): Someone requested this.
+
+  Revision 1.28  1998/06/11 02:26:50  yosh
+  changed things to use GTK_HAVE_FEATURES_1_1_0 instead of HAVE_DEVGTK...
+  installed headers depending on config.h stuff is bad.
+
+  -Yosh
+
+  Revision 1.27  1998/06/10 17:15:25  gregm
+  Wed Jun 10 13:07:09 EDT 1998 Gregory McLean <gregm@comstar.net>
+
+          * Wheee libgnomeui now compiles (with the exception of the
+            canvas stuff) under 1.0.x again. It also compiles under 1.1
+            for thoose of you that like to bleed. Please please if you
+            add code that _requires_ gtk 1.1 shield it with GTK_HAVE_FEATURES_1_1_0
+            so us boring folks can continue to get stuff done.
+
+  Revision 1.26  1998/06/07 17:58:21  pavlov
+  updates to make gnome-libs compile with new gtk1.1
+
+  i havn't tested this yet, other than knowing it compiles.  i will in a minute,
+  but my gtk is fooed at the moment, and button's arn't showing labels :)
+
+  -pav
+
   Revision 1.25  1998/05/25 16:31:18  sopwith
   Move log msgs to bottom
 
