@@ -18,7 +18,7 @@
 #define DEFAULT_ROW_SPACING  6
 #define DEFAULT_COL_SPACING  6
 #define DEFAULT_TEXT_SPACING 4
-#define DEFAULT_ICON_BORDER  4
+#define DEFAULT_ICON_BORDER  6
 #define DEFAULT_WIDTH        70
 #define SCROLLBAR_SPACING    5 /* this is the same value as in GtkCList */
 
@@ -186,6 +186,7 @@ get_icon_num_from_xy (GnomeIconList *ilist, int x, int y, int *num, int *on_spac
 	if (ilist->icons == 0) {
 		*num = -1;
 		*on_spacing = TRUE;
+		return;
 	}
 
 	x += ilist->x_offset;
@@ -233,6 +234,43 @@ get_icon_xy_from_num (GnomeIconList *ilist, int pos, int *x, int *y)
 	*y = row * (ilist->max_icon_height + ilist->row_spacing) - ilist->y_offset;
 }
 
+static void
+draw_rounded_box (GnomeIconList *ilist, GdkGC *bg_gc, Icon *icon,
+		  int x, int y, int width, int height)
+{
+	const int border = ilist->icon_border;
+
+	/* Rounded corners */
+	gdk_draw_arc (ilist->ilist_window, bg_gc, TRUE,
+		      x,  y, border * 2, border * 2, 
+		      90 * 64, 90 * 64);
+	gdk_draw_arc (ilist->ilist_window, bg_gc, TRUE,
+		      x + width  - border * 2,
+		      y, 
+		      border * 2, border * 2, 
+		      0 * 64, 90 * 64);
+	gdk_draw_arc (ilist->ilist_window, bg_gc, TRUE,
+		      x,  y + height - border * 2,
+		      border * 2, border * 2, 
+		      180 * 64, 90 * 64);
+	gdk_draw_arc (ilist->ilist_window, bg_gc, TRUE,
+		      x + width - border * 2,  y + height - border * 2,
+		      border * 2, border * 2, 
+		      270 * 64, 90 * 64);
+	/* Big rectangle */
+	gdk_draw_rectangle (ilist->ilist_window, bg_gc, TRUE,
+			    x + ilist->icon_border,
+			    y,
+			    icon->ti->width,
+			    icon->ti->height + border * 2);
+	/* Small one */
+	gdk_draw_rectangle (ilist->ilist_window, bg_gc, TRUE,
+			    x,
+			    y + ilist->icon_border,
+			    icon->ti->width  + border * 2,
+			    icon->ti->height);
+}
+ 
 static void
 draw_icon (GnomeIconList *ilist, Icon *icon, int x, int y, GdkRectangle *area)
 {
@@ -283,14 +321,6 @@ draw_icon (GnomeIconList *ilist, Icon *icon, int x, int y, GdkRectangle *area)
 			bg_gc = style->bg_gc[GTK_STATE_PRELIGHT];
 	}
 
-	/* Background */
-
-	gdk_draw_rectangle (ilist->ilist_window,
-			    bg_gc,
-			    TRUE,
-			    aarea.x, aarea.y,
-			    aarea.width, aarea.height);
-
 	/* Calculate positions */
 
 	width = icon->im ? icon->im->rgb_width : 0;
@@ -302,6 +332,10 @@ draw_icon (GnomeIconList *ilist, Icon *icon, int x, int y, GdkRectangle *area)
 		ypix = (ilist->max_icon_height - height) / 2;
 		xtext = 0;
 		ytext = 0;
+		/* Background */
+		gdk_draw_rectangle (ilist->ilist_window, bg_gc, TRUE,
+				    aarea.x,aarea.y,aarea.width, aarea.height);
+
 		break;
 
 	case GNOME_ICON_LIST_TEXT_BELOW:
@@ -309,7 +343,11 @@ draw_icon (GnomeIconList *ilist, Icon *icon, int x, int y, GdkRectangle *area)
 		ypix = ilist->icon_border + (ilist->max_pixmap_height - height) / 2;
 		xtext = (ilist->max_icon_width - icon->ti->width) / 2;
 		ytext = ilist->icon_border + ilist->max_pixmap_height + ilist->text_spacing;
-
+		draw_rounded_box (ilist, bg_gc, icon,
+				  x + xtext - ilist->icon_border,
+				  y + ytext - ilist->icon_border,
+				  icon->ti->width  + ilist->icon_border * 2,
+				  icon->ti->height + ilist->icon_border * 2);
 		break;
 
 	case GNOME_ICON_LIST_TEXT_RIGHT:
@@ -318,6 +356,10 @@ draw_icon (GnomeIconList *ilist, Icon *icon, int x, int y, GdkRectangle *area)
 		xtext = ilist->icon_border + ilist->max_pixmap_width + ilist->text_spacing;
 		ytext = (ilist->max_icon_height - icon->ti->height) / 2;
 
+		/* Background */
+		gdk_draw_rectangle (ilist->ilist_window, bg_gc, TRUE,
+				    aarea.x, aarea.y,aarea.width,aarea.height);
+
 		break;
 
 	default:
@@ -1273,7 +1315,7 @@ toggle_icon (GnomeIconList *ilist, int num, GdkEvent *event)
 		if ( selected_icon && (selected_icon->state == GTK_STATE_SELECTED) && (event->button.button == 1) )
 			gtk_signal_emit (GTK_OBJECT (ilist), ilist_signals[UNSELECT_ICON],
 					 num, event);
-		else
+		else if (event->button.button == 1)
 			gtk_signal_emit (GTK_OBJECT (ilist), ilist_signals[SELECT_ICON],
 					 num, event);
 
@@ -1290,8 +1332,9 @@ toggle_icon (GnomeIconList *ilist, int num, GdkEvent *event)
 			i++;
 		}
 
-		gtk_signal_emit (GTK_OBJECT (ilist), ilist_signals[SELECT_ICON],
-				 num, event);
+		if  (event->button.button == 1)
+		    gtk_signal_emit (GTK_OBJECT (ilist), ilist_signals[SELECT_ICON],
+				     num, event);
 
 		break;
 
@@ -1389,8 +1432,10 @@ gnome_icon_list_button_press (GtkWidget *widget, GdkEventButton *event)
 
 	get_icon_num_from_xy (ilist, event->x, event->y, &num, &on_spacing);
 
-	if (on_spacing)
+	if (on_spacing) {
+		ilist->last_clicked = -1;
 		return FALSE;
+	}
 
 	icon = g_list_nth (ilist->icon_list, num)->data;
 	if (icon->state == GTK_STATE_SELECTED && event->type != GDK_2BUTTON_PRESS && (event->button == 1) ){
@@ -1483,7 +1528,7 @@ gnome_icon_list_set_policy (GnomeIconList *ilist,
 
 
 static Icon *
-icon_new_from_imlib (GnomeIconList *ilist, GdkImlibImage *im, char *text)
+icon_new_from_imlib (GnomeIconList *ilist, GdkImlibImage *im, const char *text)
 {
 	Icon *icon;
 
@@ -1519,7 +1564,7 @@ icon_new_from_imlib (GnomeIconList *ilist, GdkImlibImage *im, char *text)
 }
 
 static Icon *
-icon_new (GnomeIconList *ilist, char *icon_filename, char *text)
+icon_new (GnomeIconList *ilist, char *icon_filename, const char *text)
 {
 	GdkImlibImage *im;
 
@@ -1595,7 +1640,8 @@ gnome_icon_list_append_imlib (GnomeIconList *ilist, GdkImlibImage *im, char *tex
 }
 
 int
-gnome_icon_list_append (GnomeIconList *ilist, char *icon_filename, char *text)
+gnome_icon_list_append (GnomeIconList *ilist, const char *icon_filename, 
+			const char *text)
 {
 	Icon *icon;
 
@@ -1629,7 +1675,9 @@ sync_selection (GnomeIconList *ilist, int pos, SyncType type)
 }
 
 void
-gnome_icon_list_insert (GnomeIconList *ilist, int pos, char *icon_filename, char *text)
+gnome_icon_list_insert (GnomeIconList *ilist, int pos, 
+			const char *icon_filename, 
+			const char *text)
 {
 	Icon *icon;
 
@@ -2114,7 +2162,8 @@ gnome_icon_list_set_icon_border (GnomeIconList *ilist, int spacing)
 }
 
 void
-gnome_icon_list_set_separators (GnomeIconList *ilist, char *separators)
+gnome_icon_list_set_separators (GnomeIconList *ilist, 
+				const char *separators)
 {
 	g_return_if_fail (ilist != NULL);
 	g_return_if_fail (GNOME_IS_ICON_LIST (ilist));
