@@ -30,7 +30,7 @@
 
 #include "libgnome/gnome-defs.h"
 #include "libgnome/gnome-util.h"
-#include "libgnome/gnome-i18n.h"
+#include "libgnome/gnome-i18nP.h"
 #include "libgnome/gnome-config.h"
 #include "gnome-stock.h"
 #include "gnome-pixmap.h"
@@ -121,7 +121,6 @@ gnome_stock_pixmap_widget_state_changed(GtkWidget *widget, guint prev_state)
 	GnomeStockPixmapWidget *w = GNOME_STOCK_PIXMAP_WIDGET(widget);
 	GnomePixmap *pixmap;
 
-	if (!GTK_WIDGET_REALIZED(widget)) return;
 	pixmap = NULL;
 	if (GTK_WIDGET_HAS_FOCUS(widget)) {
 		if (!w->focused) {
@@ -157,22 +156,6 @@ gnome_stock_pixmap_widget_state_changed(GtkWidget *widget, guint prev_state)
 
 
 
-static void
-gnome_stock_pixmap_widget_realize(GtkWidget *widget)
-{
-	GnomeStockPixmapWidget *p;
-
-	g_return_if_fail(widget != NULL);
-	if (parent_class)
-		(* GTK_WIDGET_CLASS(parent_class)->realize)(widget);
-	p = GNOME_STOCK_PIXMAP_WIDGET(widget);
-	if (p->pixmap) return;
-	g_return_if_fail(p->window != NULL);
-	gnome_stock_pixmap_widget_state_changed(widget, 0);
-}
-
-
-
 static void
 gnome_stock_pixmap_widget_size_request(GtkWidget *widget,
 				       GtkRequisition *requisition)
@@ -181,13 +164,9 @@ gnome_stock_pixmap_widget_size_request(GtkWidget *widget,
 	g_return_if_fail(requisition != NULL);
 	g_return_if_fail(GNOME_IS_STOCK_PIXMAP_WIDGET(widget));
 
-	if (!GNOME_STOCK_PIXMAP_WIDGET(widget)->pixmap) {
-		requisition->width = GNOME_STOCK_PIXMAP_WIDGET(widget)->width;
-		requisition->height = GNOME_STOCK_PIXMAP_WIDGET(widget)->height;
-	} else {
+	if (GNOME_STOCK_PIXMAP_WIDGET(widget)->pixmap)
 		gtk_widget_size_request(GTK_WIDGET(GNOME_STOCK_PIXMAP_WIDGET(widget)->pixmap),
 					requisition);
-	}
 }
 
 
@@ -199,8 +178,6 @@ gnome_stock_pixmap_widget_class_init(GnomeStockPixmapWidgetClass *klass)
 	object_class->destroy = gnome_stock_pixmap_widget_destroy;
 	((GtkWidgetClass *)klass)->state_changed =
 		gnome_stock_pixmap_widget_state_changed;
-	((GtkWidgetClass *)klass)->realize =
-		gnome_stock_pixmap_widget_realize;
 	((GtkWidgetClass *)klass)->size_request =
 		gnome_stock_pixmap_widget_size_request;
 }
@@ -272,6 +249,9 @@ gnome_stock_pixmap_widget_new(GtkWidget *window, const char *icon)
 		p->height = entry->any.height;
 	}
 	p->window = window;
+
+	gnome_stock_pixmap_widget_state_changed(w, 0);
+
 	return w;
 }
 
@@ -444,11 +424,15 @@ struct _default_entries_data entries_data[] = {
 	{GNOME_STOCK_PIXMAP_HELP, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_help, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_PRINT, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_print, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_SEARCH, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_search, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
+	{GNOME_STOCK_PIXMAP_SRCHRPL, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_search_replace, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_BACK, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_left_arrow, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_FORWARD, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_right_arrow, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
+	{GNOME_STOCK_PIXMAP_FIRST, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_first, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
+	{GNOME_STOCK_PIXMAP_LAST, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_last, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_HOME, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_home, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_STOP, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_stop, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_REFRESH, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_refresh, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
+	{GNOME_STOCK_PIXMAP_UNDELETE, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_undelete, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_OPEN, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_open, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_CLOSE, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_close, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
 	{GNOME_STOCK_PIXMAP_COPY, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_copy, TIGERT_W, TIGERT_H, TIGERT_W, TIGERT_H},
@@ -488,6 +472,8 @@ struct _default_entries_data entries_data[] = {
 	{GNOME_STOCK_BUTTON_YES, GNOME_STOCK_PIXMAP_REGULAR, N_("Yes"), imlib_button_yes, TB_W, TB_H, TB_W, TB_H},
 	{GNOME_STOCK_BUTTON_NO, GNOME_STOCK_PIXMAP_REGULAR, N_("No"), imlib_button_no, TB_W, TB_H, TB_W, TB_H},
 	{GNOME_STOCK_BUTTON_HELP, GNOME_STOCK_PIXMAP_REGULAR, N_("Help"), imlib_help, TIGERT_W, TIGERT_H, TB_W, TB_H},
+	{GNOME_STOCK_BUTTON_NEXT, GNOME_STOCK_PIXMAP_REGULAR, N_("Help"), imlib_right_arrow, TIGERT_W, TIGERT_H, TB_W, TB_H},
+	{GNOME_STOCK_BUTTON_PREV, GNOME_STOCK_PIXMAP_REGULAR, N_("Help"), imlib_left_arrow, TIGERT_W, TIGERT_H, TB_W, TB_H},
 	{GNOME_STOCK_MENU_NEW, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_new, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_SAVE, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_save, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_SAVE_AS, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_save_as, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
@@ -504,11 +490,15 @@ struct _default_entries_data entries_data[] = {
 	{GNOME_STOCK_MENU_REDO, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_redo, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_PRINT, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_print, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_SEARCH, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_search, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
+	{GNOME_STOCK_MENU_SRCHRPL, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_search_replace, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_BACK, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_left_arrow, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_FORWARD, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_right_arrow, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
+	{GNOME_STOCK_MENU_FIRST, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_first, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
+	{GNOME_STOCK_MENU_LAST, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_last, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_HOME, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_home, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_STOP, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_stop, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_REFRESH, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_refresh, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
+	{GNOME_STOCK_MENU_UNDELETE, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_undelete, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_MAIL, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_mail, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_MAIL_RCV, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_mail_receive, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
 	{GNOME_STOCK_MENU_MAIL_SND, GNOME_STOCK_PIXMAP_REGULAR, NULL, imlib_mail_send, TIGERT_W, TIGERT_H, MENU_W, MENU_H},
@@ -691,7 +681,6 @@ build_disabled_pixmap(GtkWidget *window, GnomePixmap **inout_pixmap)
 #endif
 
 	g_return_if_fail(window != NULL);
-	g_return_if_fail(GTK_WIDGET_REALIZED(window));
 
 	gdk_window_get_size(pixmap, &w, &h);
 	visual = gtk_widget_get_visual(GTK_WIDGET(*inout_pixmap));
@@ -932,7 +921,7 @@ gnome_pixmap_button(GtkWidget *pixmap, const char *text)
 			entry->any.height = req.height;
 			entry->any.label = NULL;
 			entry->gpixmap.pixmap = GNOME_PIXMAP(pixmap);
-			sprintf(s, "%lx", (long)pixmap);
+			g_snprintf(s, 32, "%lx", (long)pixmap);
 			gnome_stock_pixmap_register(s, GNOME_STOCK_PIXMAP_REGULAR, entry);
 			pixmap = gnome_stock_pixmap_widget(button, s);
 		}
@@ -1019,11 +1008,17 @@ gnome_stock_menu_item(const char *type, const char *text)
 		gtk_widget_show(w);
 		gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 0);
 
-		w = gtk_label_new(text);
-		gtk_widget_show(w);
-		gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 0);
-
 		menu_item = gtk_menu_item_new();
+#ifdef	GTK_HAVE_FEATURES_1_1_0
+		w = gtk_accel_label_new (text);
+		gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (w), menu_item);
+#else	/* !GTK_HAVE_FEATURES_1_1_0 */
+		w = gtk_label_new(text);
+#endif	/* !GTK_HAVE_FEATURES_1_1_0 */
+		gtk_misc_set_alignment (GTK_MISC (w), 0.0, 0.5);
+		gtk_widget_show(w);
+		gtk_box_pack_start(GTK_BOX(hbox), w, TRUE, TRUE, 0);
+
 		gtk_container_add(GTK_CONTAINER(menu_item), hbox);
 	} else {
 		menu_item = gtk_menu_item_new_with_label(text);
