@@ -28,7 +28,7 @@
 #include <gtk/gtkpixmap.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkbutton.h>
-#include <libgnomeui/gnome-pixmap.h>
+#include "gnome-pixmap.h"
 /* #include <gdk_imlib.h> */
 
 
@@ -104,8 +104,11 @@ BEGIN_GNOME_DECLS
 #define GNOME_STOCK_PIXMAP_SCORES      "Scores"
 #define GNOME_STOCK_PIXMAP_PRINT       "Print"
 #define GNOME_STOCK_PIXMAP_SEARCH      "Search"
+#define GNOME_STOCK_PIXMAP_SRCHRPL     "Search/Replace"
 #define GNOME_STOCK_PIXMAP_BACK        "Back"
 #define GNOME_STOCK_PIXMAP_FORWARD     "Forward"
+#define GNOME_STOCK_PIXMAP_FIRST       "First"
+#define GNOME_STOCK_PIXMAP_LAST        "Last"
 #define GNOME_STOCK_PIXMAP_HOME        "Home"
 #define GNOME_STOCK_PIXMAP_STOP        "Stop"
 #define GNOME_STOCK_PIXMAP_REFRESH     "Refresh"
@@ -121,6 +124,7 @@ BEGIN_GNOME_DECLS
 #define GNOME_STOCK_PIXMAP_MAIL_NEW    "New Mail"
 #define GNOME_STOCK_PIXMAP_TRASH       "Trash"
 #define GNOME_STOCK_PIXMAP_TRASH_FULL  "Trash Full"
+#define GNOME_STOCK_PIXMAP_UNDELETE    "Undelete"
 #define GNOME_STOCK_PIXMAP_SPELLCHECK  "Spellchecker"
 #define GNOME_STOCK_PIXMAP_MIC         "Microphone"
 #define GNOME_STOCK_PIXMAP_LINE_IN     "Line In"
@@ -302,7 +306,7 @@ GtkWidget             *gnome_stock_pixmap_widget   (GtkWidget *window,
 void gnome_stock_pixmap_widget_set_icon(GnomeStockPixmapWidget *widget,
 					const char *icon);
 
-/* register a pixmap. returns non-zero, if successfull */
+/* register a pixmap. returns non-zero, if successful */
 gint                   gnome_stock_pixmap_register (const char *icon,
 						    const char *subtype,
                                                     GnomeStockPixmapEntry *entry);
@@ -336,6 +340,8 @@ void		      gnome_button_can_default    (GtkButton *button,
 #define GNOME_STOCK_BUTTON_CLOSE  "Button_Close"
 #define GNOME_STOCK_BUTTON_APPLY  "Button_Apply"
 #define GNOME_STOCK_BUTTON_HELP   "Button_Help"
+#define GNOME_STOCK_BUTTON_NEXT   "Button_Next"
+#define GNOME_STOCK_BUTTON_PREV   "Button_Prev"
 
 /* returns a default button widget for dialogs */
 GtkWidget             *gnome_stock_button          (const char *type);
@@ -368,8 +374,11 @@ GtkWidget             *gnome_stock_or_ordinary_button (const char *type);
 #define GNOME_STOCK_MENU_REDO         "Menu_Redo"
 #define GNOME_STOCK_MENU_PRINT        "Menu_Print"
 #define GNOME_STOCK_MENU_SEARCH       "Menu_Search"
+#define GNOME_STOCK_MENU_SRCHRPL      "Menu_Search/Replace"
 #define GNOME_STOCK_MENU_BACK         "Menu_Back"
 #define GNOME_STOCK_MENU_FORWARD      "Menu_Forward"
+#define GNOME_STOCK_MENU_FIRST        "Menu_First"
+#define GNOME_STOCK_MENU_LAST         "Menu_Last"
 #define GNOME_STOCK_MENU_HOME         "Menu_Home"
 #define GNOME_STOCK_MENU_STOP         "Menu_Stop"
 #define GNOME_STOCK_MENU_REFRESH      "Menu_Refresh"
@@ -381,6 +390,7 @@ GtkWidget             *gnome_stock_or_ordinary_button (const char *type);
 #define GNOME_STOCK_MENU_MAIL_NEW     "Menu_New Mail"
 #define GNOME_STOCK_MENU_TRASH        "Menu_Trash"
 #define GNOME_STOCK_MENU_TRASH_FULL   "Menu_Trash Full"
+#define GNOME_STOCK_MENU_UNDELETE     "Menu_Undelete"
 #define GNOME_STOCK_MENU_SPELLCHECK   "Menu_Spellchecker"
 #define GNOME_STOCK_MENU_MIC          "Menu_Microphone"
 #define GNOME_STOCK_MENU_LINE_IN      "Menu_Line In"
